[![Build Status](https://travis-ci.com/RustyBower/sopel-stocks.svg?branch=master)](https://travis-ci.com/RustyBower/sopel-stocks)
[![Maintainability](https://api.codeclimate.com/v1/badges/719931784d9152a50a09/maintainability)](https://codeclimate.com/github/RustyBower/sopel-stocks/maintainability)
[![Test Coverage](https://api.codeclimate.com/v1/badges/719931784d9152a50a09/test_coverage)](https://codeclimate.com/github/RustyBower/sopel-stocks/test_coverage)
[![PyPI version](https://badge.fury.io/py/sopel-modules.stocks.svg)](https://badge.fury.io/py/sopel-modules.stocks)

# sopel-stocks
sopel-stocks is an stock lookup plugin for Sopel

## Requirements
#### API Key
```
https://www.alphavantage.co/support/#api-key
https://iexcloud.io/console/tokens
```

#### Python Requirements
```
requests
sopel
```

## Usage
```
.stock djia
DJIA $26559.5 110 (0.42%)⬆

.stock msft
MSFT $123.37 1.6 (1.31%)⬆
```
